---
kernelspec:
  display_name: Maxima
  language: maxima
  name: maxima
---

## maxima misc

```{code-cell} maxima
kill(all)$
```

```{code-cell} maxima
f(x) := 1/(x^2+l^2)^(3/2);
```

```{code-cell} maxima
integrate(f(x), x);
```

```{code-cell} maxima
tex(%)$
```

```{code-cell} maxima

```
